@@ -3,7 +3,7 @@ pg_statviz - stats visualization and time series analysis
 """
 
 __author__ = "Jimmy Angelakos"
-__copyright__ = "Copyright (c) 2025 Jimmy Angelakos"
+__copyright__ = "Copyright (c) 2026 Jimmy Angelakos"
 __license__ = "PostgreSQL License"
 
 import argparse
@@ -28,8 +28,8 @@ from pg_statviz.libs.info import getinfo
 @arg('-W', '--password', action='store_true',
      help="force password prompt (should happen automatically)")
 @arg('-D', '--daterange', nargs=2, metavar=('FROM', 'TO'), type=str,
-     help="date range to be analyzed in ISO 8601 format e.g. 2023-01-01T00:00"
-          + " 2023-01-01T23:59")
+     help="date range to be analyzed in ISO 8601 format e.g. 2026-01-01T00:00"
+          + " 2026-01-01T23:59")
 @arg('-O', '--outputdir', help="output directory")
 @arg('--info', help=argparse.SUPPRESS)
 @arg('--conn', help=argparse.SUPPRESS)
@@ -70,7 +70,16 @@ def io(*, dbname=getpass.getuser(), host="/var/run/postgresql", port="5432",
 
     data = cur.fetchall()
     if not data:
-        raise SystemExit("No pg_statviz snapshots found in this database")
+        cur.execute("""SELECT
+                    (current_setting('server_version_num')::int >= 160000)
+                    AS version_ok""")
+        versioncheck = cur.fetchone()['version_ok']
+        if not versioncheck:
+            _logger.warning("I/O analysis is only available from "
+                            + "PostgreSQL release 16 onwards")
+            return
+        else:
+            raise SystemExit("No pg_statviz snapshots found in this database")
 
     tstamps = [ts['snapshot_tstamp'] for ts in data]
     blcksz = int(data[0]['block_size'])
@@ -251,7 +260,8 @@ def calc_iostats(data, blcksz=8192):
     iokinds = []
     for snapshot in iostats:
         for entry in snapshot:
-            # PG18+ has read_bytes/write_bytes columns, older versions need conversion
+            # PG18+ has read_bytes/write_bytes columns,
+            # older versions need conversion
             if 'read_bytes' in entry:
                 r = entry['read_bytes']
                 if r:
@@ -294,7 +304,7 @@ def calc_iorates(data, iokinds, blcksz=8192):
                          .total_seconds())
                     v1, v2 = 0, 0
                     # PG18+ has read_bytes/write_bytes columns
-                    rw_bytes = f"{rw[:-1]}_bytes"  # reads->read_bytes, writes->write_bytes
+                    rw_bytes = f"{rw[:-1]}_bytes"
                     for entry in data[i]['io_stats']:
                         if {'backend_type': entry['backend_type'],
                                 'object': entry['object'],
