@@ -4,9 +4,9 @@ pg_statviz - stats visualization and time series analysis
 """
 
 __author__ = "Jimmy Angelakos"
-__copyright__ = "Copyright (c) 2025 Jimmy Angelakos"
+__copyright__ = "Copyright (c) 2026 Jimmy Angelakos"
 __license__ = "PostgreSQL License"
-__version__ = "0.8"
+__version__ = "0.9"
 
 import sys
 from argh import ArghParser
@@ -14,9 +14,13 @@ from pg_statviz.modules.analyze import analyze
 from pg_statviz.modules.buf import buf
 from pg_statviz.modules.cache import cache
 from pg_statviz.modules.checkp import checkp
+from pg_statviz.modules.checksum import checksum
+from pg_statviz.modules.conf import conf
 from pg_statviz.modules.conn import conn
 from pg_statviz.modules.io import io
 from pg_statviz.modules.lock import lock
+from pg_statviz.modules.repl import repl
+from pg_statviz.modules.slru import slru
 from pg_statviz.modules.tuple import tuple
 from pg_statviz.modules.wait import wait
 from pg_statviz.modules.wal import wal
@@ -35,8 +39,8 @@ def main():
     p.add_argument('--version', action='version',
                    version=f"pg_statviz {__version__}")
 
-    p.add_commands([analyze, buf, cache, checkp, conn, io, lock, tuple, wait,
-                    wal, xact])
+    p.add_commands([analyze, buf, cache, checkp, checksum, conf, conn, io,
+                    lock, repl, slru, tuple, wait, wal, xact])
     p.set_default_command(analyze)
     p.dispatch()
 
